# Cytomine-python-client

When using our software, we kindly ask you to cite our website url and related publications in all your work (publications, studies, oral presentations,...). In particular, we recommend to cite (Marée et al., Bioinformatics 2016) paper, and to use our logo when appropriate. See our license files for additional details.

- URL: http://www.cytomine.org
- Logo: http://www.cytomine.org/sites/default/files/inline-images/logo-300-org.png
- Scientific paper: Raphaël Marée, Loïc Rollus, Benjamin Stévens, Renaud Hoyoux, Gilles Louppe, Rémy Vandaele, Jean-Michel Begon, Philipp Kainz, Pierre Geurts and Louis Wehenkel. Collaborative analysis of multi-gigapixel imaging data using Cytomine, Bioinformatics, DOI: 10.1093/bioinformatics/btw013, 2016. https://doi.org/10.1093/bioinformatics/btw013


Cytomine (http://doc.cytomine.org) client and utilities in Python.

Cytomine client contains functions to import/export data (projects, ontologies, images, users, annotations, softwares, ...) from/to Cytomine core server based on the RESTful API.

Cytomine utilities contains various functions including ones to access whole slide images (tiles,...) and basic image processing tools.

See examples in https://github.com/cytomine/Cytomine-python-client/tree/master/client/examples and https://github.com/cytomine/Cytomine-python-client/tree/master/utilities/examples

The client is automatically installed with the Docker/Bootstrap procedure, however it is possible to install it independently on remote computers. See installation instructions here : [https://doc.cytomine.org/Python-client](https://doc.cytomine.org/Python-client?structure=DataScientists)

